CreateMintConfig class

Configuration for getCreateMintInstructionPlan.

Constructors

CreateMintConfig({Address? tokenProgram, Address? systemProgram})
Creates a CreateMintConfig.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemProgram → Address?
System program address. Defaults to systemProgramAddress.
final
tokenProgram → Address?
Token program address. Defaults to tokenProgramAddress.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited