MintToCheckedInstructionData class

The discriminator field name: 'discriminator'. Offset: 0.

Annotations
  • @immutable

Constructors

MintToCheckedInstructionData({int discriminator = 14, required BigInt amount, required int decimals})
const

Properties

amount → BigInt
final
decimals → int
final
discriminator → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited